@@ -128,6 +128,7 @@ class RelativeSpectralResponse(object):
         self.rsrs_norm01 = {}  # RSR values with 1 nm precision
         self.bands = []
         self.wvl = []
+        self.fwhm = []
         self.wvl_unit = wvl_unit
         self.specres_nm = specres_nm
         self.format_bandnames = format_bandnames
@@ -181,7 +182,7 @@ class RelativeSpectralResponse(object):
             df = df.join(Series(rsrs_tgtres, index=wvls_tgtres, name=bandname))
 
         df = df.fillna(0)
-        wvl = np.array(df.index.astype(np.float))
+        wvl = np.array(df.index.astype(float))
         rsrs_norm01 = df.to_dict(orient='series')  # type: Dict[Series]
 
         ################
@@ -189,7 +190,7 @@ class RelativeSpectralResponse(object):
         ################
 
         for bN in rsrs_norm01:
-            self.rsrs_norm01[bN] = rsr = np.array(rsrs_norm01[bN], dtype=np.float)
+            self.rsrs_norm01[bN] = rsr = np.array(rsrs_norm01[bN], dtype=float)
             self.rsrs[bN] = rsr / np.trapz(x=wvl, y=rsr)  # TODO seems like we NEED nanometers here; BUT WHY??
 
         self.rsrs_wvl = np.array(wvl)
@@ -202,8 +203,20 @@ class RelativeSpectralResponse(object):
         self.wvl = np.array([np.trapz(x=self.rsrs_wvl, y=self.rsrs_wvl * self.rsrs[band]) for band in self.bands])
         # self.wvl = self.wvl if self.wvl_unit == 'micrometers' else np.array([int(i) for i in self.wvl])
 
-        self.rsrs_wvl = self.rsrs_wvl if self.wvl_unit == 'nanometers' else self.rsrs_wvl / 1000
-        self.wvl = self.wvl if self.wvl_unit == 'nanometers' else self.wvl / 1000
+        # calculate FWHM
+        fwhm = []
+        for band in self.bands:
+            rsr_band = self.rsrs_norm01[band]
+            rsr_halfmax = np.max(rsr_band) / 2.
+            wvls_within_fullwidth = self.rsrs_wvl[rsr_band >= rsr_halfmax]
+            fwhm.append(np.max(wvls_within_fullwidth) - np.min(wvls_within_fullwidth))
+        self.fwhm = np.array(fwhm)
+
+        # force nanometer output
+        if self.wvl_unit == 'micrometers':
+            self.rsrs_wvl *= 1000
+            self.wvl *= 1000
+            self.fwhm *= 1000
 
         self.conv.update({key: value for key, value in zip(self.bands, self.wvl)})
         self.conv.update({value: key for key, value in zip(self.bands, self.wvl)})
